@@ -273,11 +273,8 @@ line2pointsn <- function(l){
 #' rf_no_id$id # [1] "1" "2" "3" "4"
 #' rf_with_id = line2route(l, l_id = "All")
 #' rf_with_id$id # [1] 38 10 44
-#' # demo with parallel version spliting route API requests over multiple CPU processes
-#' rf_parr <- line2route(l = l, n_processes = 4)
-#' l = flowlines[1:2,]
 #' rf_with_err = line2route(l,  reporterrors = T)
-#' # Now rf_with_err$error[2] has the correct error message
+#' # rf_with_err$error[2] has the correct error message
 #' }
 line2route <- function(l, route_fun = "route_cyclestreet", n_print = 10, list_output = FALSE, l_id = NA, n_processes = 1, ...){
   FUN <- match.fun(route_fun)
@@ -289,32 +286,21 @@ line2route <- function(l, route_fun = "route_cyclestreet", n_print = 10, list_ou
     e
   }
 
-  if(n_processes > 1){
-    n_processes <- min(c(n_processes, n_ldf))
-    cl <- parallel::makeCluster(n_processes)
-    doParallel::registerDoParallel(cl)
-  }
-
-  if(n_processes > 1){
-    rc <- foreach::foreach(i = 1:n_ldf, .errorhandling = "pass") %dopar% {
+  rc <- as.list(rep(NA, length(l)))
+  for(i in 1:n_ldf){
+    rc[[i]] <- tryCatch({
       FUN(from = c(ldf$fx[i], ldf$fy[i]), to = c(ldf$tx[i], ldf$ty[i]), ...)
-    }
-    parallel::stopCluster(cl)
-  } else {
-    rc <- as.list(rep(NA, length(l)))
-    for(i in 1:n_ldf){
-      rc[[i]] <- tryCatch({
-        FUN(from = c(ldf$fx[i], ldf$fy[i]), to = c(ldf$tx[i], ldf$ty[i]), ...)
-      }, error = error_fun)
-      perc_temp <- i %% round(n_ldf / n_print)
-      # print % of distances calculated
-      if(!is.na(perc_temp) & perc_temp == 0){
-        message(paste0(round(100 * i/n_ldf), " % out of ", n_ldf, " distances calculated"))
-      }
+    }, error = error_fun)
+    perc_temp <- i %% round(n_ldf / n_print)
+    # print % of distances calculated
+    if(!is.na(perc_temp) & perc_temp == 0){
+      message(paste0(round(100 * i/n_ldf), " % out of ", n_ldf, " distances calculated"))
     }
   }
 
-  if(!list_output){
+  if(list_output) {
+    r <- rc
+  } else {
     # Set the names based on the first non failing line (then exit loop)
     for(i in 1:n_ldf){
       if(grepl("Spatial.*DataFrame", class(rc[[i]]))[1]) {
