@@ -108,7 +108,8 @@ buff_geo <- function(shp, width, ..., silent = TRUE){
 #' @export
 #' @examples
 #' data("routes_fast")
-#' r_toptail <- toptailgs(routes_fast, toptail_dist = 300)
+#' rf = routes_fast[!is.na(routes_fast$length),]
+#' r_toptail <- toptailgs(rf, toptail_dist = 300)
 #' plot(routes_fast, lwd = 3)
 #' plot(r_toptail, col = "red", add = TRUE)
 #' plot(cents, add = TRUE)
@@ -204,7 +205,7 @@ toptail_buff <- function(l, buff, ...){
     if(!exists("out")){
       out <- l2
     } else {
-      out <- maptools::spRbind(out, l2)
+      out <- raster::bind(out, l2)
     }
   }
   proj4string(out) <- proj4string(l)
