@@ -1,5 +1,7 @@
 ## ---- include=FALSE------------------------------------------------------
 library(stplanr)
+build = require("tmap") & curl::has_internet()
+knitr::opts_chunk$set(eval = build)
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  install.packages("stplanr")
@@ -28,42 +30,37 @@ head(cents)
 
 ## ------------------------------------------------------------------------
 library(tmap)
-library(tmaptools)
-osm_tiles = read_osm(bb(cents, 1.4))
-(map = qtm(osm_tiles) +
-  qtm(cents, symbols.size = 5) )
+tmap_mode("view")
+qtm(cents, symbols.size = 5)
 
 ## ------------------------------------------------------------------------
 flow_single_line = flow[4,] # select only the first line
 desire_line_single = od2line(flow = flow_single_line, zones = cents)
 
 ## ------------------------------------------------------------------------
-map +
-  qtm(desire_line_single, lines.lwd = 5)
+qtm(desire_line_single, lines.lwd = 5)
 
 ## ------------------------------------------------------------------------
 l = od2line(flow = flow, zones = cents)
+l = l[! l$Area.of.residence == l$Area.of.workplace,]
 
 ## ---- eval=FALSE---------------------------------------------------------
-#  map +
-#    qtm(l)
+#  qtm(l)
 
 ## ------------------------------------------------------------------------
-map +
-  tm_shape(l) + tm_lines(lwd = "All", scale = 10)
+qtm(l, lines.lwd = "All", scale = 10)
 
 ## ------------------------------------------------------------------------
-map +
-  tm_shape(l) + tm_lines(lwd = "All", scale = 10, col = "Bicycle")
+tm_shape(l) + tm_lines(lwd = "All", scale = 10, col = "Bicycle")
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  r = line2route(l) # requires the a cyclestreets.net API key
 
 ## ---- echo=FALSE---------------------------------------------------------
 r = routes_fast
+r = r[!is.na(r$length), ]
 
 ## ------------------------------------------------------------------------
 r@data = cbind(r@data, l@data)
-map +
-  tm_shape(r) + tm_lines(lwd = "All", scale = 10, col = "Bicycle")
+tm_shape(r) + tm_lines(lwd = "All", scale = 10, col = "Bicycle")
 
